Construct a weeknumber vector from ISO 8601 year and week values.
Details
Input arguments are recycled to their common size, using
vctrs::vec_recycle_common(). Weeks outside the valid range for the
corresponding year result in NA.
Construct a weeknumber vector from ISO 8601 year and week values.
Input arguments are recycled to their common size, using
vctrs::vec_recycle_common(). Weeks outside the valid range for the
corresponding year result in NA.